==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/ResourceGuardProxyBaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * ResourceGuardProxyBase object, used in ResourceGuardProxyBaseResource
 * @property description
 * @property lastUpdatedTime
 * @property resourceGuardOperationDetails
 * @property resourceGuardResourceId
 */
public data class ResourceGuardProxyBaseArgs(
    public val description: Output<String>? = null,
    public val lastUpdatedTime: Output<String>? = null,
    public val resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null,
    public val resourceGuardResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs =
        com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .lastUpdatedTime(lastUpdatedTime?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationDetails(
                resourceGuardOperationDetails?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .resourceGuardResourceId(resourceGuardResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardProxyBaseArgs].
 */
@PulumiTagMarker
public class ResourceGuardProxyBaseArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var lastUpdatedTime: Output<String>? = null

    private var resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null

    private var resourceGuardResourceId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("giwcfmosjbfnidbe")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("cnnusyafstpuddek")
    public suspend fun lastUpdatedTime(`value`: Output<String>) {
        this.lastUpdatedTime = value
    }

    /**
     * @param value
     */
    @JvmName("aelvcffwlyybkxen")
    public suspend
    fun resourceGuardOperationDetails(`value`: Output<List<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = value
    }

    @JvmName("bklrarebgeofmyft")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: Output<ResourceGuardOperationDetailArgs>,
    ) {
        this.resourceGuardOperationDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ykobgjvwpktpyfix")
    public suspend
    fun resourceGuardOperationDetails(values: List<Output<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("vphbefjitpnkdwhe")
    public suspend fun resourceGuardResourceId(`value`: Output<String>) {
        this.resourceGuardResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("aoljoiorgsnjfvwt")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("sdhqtgrjdenytoji")
    public suspend fun lastUpdatedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUpdatedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("xnnmkrcpgpcdduls")
    public suspend
    fun resourceGuardOperationDetails(`value`: List<ResourceGuardOperationDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rflgepyutlmxrcts")
    public suspend
    fun resourceGuardOperationDetails(argument: List<suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ppfywgnmipysfxuv")
    public suspend fun resourceGuardOperationDetails(
        vararg
        argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("muywgfgndyrqhvtq")
    public suspend
    fun resourceGuardOperationDetails(argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("onapbdbptaorbihb")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: ResourceGuardOperationDetailArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("khllrovqemjewykg")
    public suspend fun resourceGuardResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardResourceId = mapped
    }

    internal fun build(): ResourceGuardProxyBaseArgs = ResourceGuardProxyBaseArgs(
        description = description,
        lastUpdatedTime = lastUpdatedTime,
        resourceGuardOperationDetails = resourceGuardOperationDetails,
        resourceGuardResourceId = resourceGuardResourceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/ResourceGuardProxyBaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * ResourceGuardProxyBase object, used in ResourceGuardProxyBaseResource
 * @property description
 * @property lastUpdatedTime
 * @property resourceGuardOperationDetails
 * @property resourceGuardResourceId
 */
public data class ResourceGuardProxyBaseArgs(
    public val description: Output<String>? = null,
    public val lastUpdatedTime: Output<String>? = null,
    public val resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null,
    public val resourceGuardResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs =
        com.pulumi.azurenative.dataprotection.inputs.ResourceGuardProxyBaseArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .lastUpdatedTime(lastUpdatedTime?.applyValue({ args0 -> args0 }))
            .resourceGuardOperationDetails(
                resourceGuardOperationDetails?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .resourceGuardResourceId(resourceGuardResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceGuardProxyBaseArgs].
 */
@PulumiTagMarker
public class ResourceGuardProxyBaseArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var lastUpdatedTime: Output<String>? = null

    private var resourceGuardOperationDetails: Output<List<ResourceGuardOperationDetailArgs>>? = null

    private var resourceGuardResourceId: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("kbqrjsdnnkatlrjm")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value
     */
    @JvmName("mvnubvfapcpwetnp")
    public suspend fun lastUpdatedTime(`value`: Output<String>) {
        this.lastUpdatedTime = value
    }

    /**
     * @param value
     */
    @JvmName("lljgauyvrywxdymc")
    public suspend
    fun resourceGuardOperationDetails(`value`: Output<List<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = value
    }

    @JvmName("ianhulnlotxxiowg")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: Output<ResourceGuardOperationDetailArgs>,
    ) {
        this.resourceGuardOperationDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("pairwjmacoemsidg")
    public suspend
    fun resourceGuardOperationDetails(values: List<Output<ResourceGuardOperationDetailArgs>>) {
        this.resourceGuardOperationDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nhhuegeyfgbieyym")
    public suspend fun resourceGuardResourceId(`value`: Output<String>) {
        this.resourceGuardResourceId = value
    }

    /**
     * @param value
     */
    @JvmName("kyglljtvykyjedjx")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value
     */
    @JvmName("hhwvoasnyjadgaiq")
    public suspend fun lastUpdatedTime(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastUpdatedTime = mapped
    }

    /**
     * @param value
     */
    @JvmName("jucajdmgoyhaabpr")
    public suspend
    fun resourceGuardOperationDetails(`value`: List<ResourceGuardOperationDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nnyjcpnymxduqyik")
    public suspend
    fun resourceGuardOperationDetails(argument: List<suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yfbdhfaclgmkrhux")
    public suspend fun resourceGuardOperationDetails(
        vararg
        argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hixahayrhwhtmkyh")
    public suspend
    fun resourceGuardOperationDetails(argument: suspend ResourceGuardOperationDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ResourceGuardOperationDetailArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("lptjehoocpilnhja")
    public suspend fun resourceGuardOperationDetails(
        vararg
        values: ResourceGuardOperationDetailArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceGuardOperationDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("wmwqgkpomaasibwh")
    public suspend fun resourceGuardResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGuardResourceId = mapped
    }

    internal fun build(): ResourceGuardProxyBaseArgs = ResourceGuardProxyBaseArgs(
        description = description,
        lastUpdatedTime = lastUpdatedTime,
        resourceGuardOperationDetails = resourceGuardOperationDetails,
        resourceGuardResourceId = resourceGuardResourceId,
    )
}
